@@ -88,6 +88,7 @@ def collect_all(root_dir, robo_file_content):
         root_dir (string): name of the directory, where to start searching
         robo_file_content (string): Robot File Content
     """
+    import pudb;pudb.set_trace()
     yield from _get_required_odoo_modules_from_robot_file(robo_file_content)
     try:
         for line in robo_file_content.splitlines():
@@ -209,8 +210,11 @@ def _select_robot_filename(file, run_all):
     if file:
         match = [x for x in map(str, testfiles) if file in x]
         if len(match) > 1:
-            click.secho("Not unique: {file}", fg="red")
-            sys.exit(-1)
+            if '/' in file:
+                match = [x for x in match if x == file]
+            if len(match) > 1:
+                click.secho("Not unique: {file}", fg="red")
+                sys.exit(-1)
 
         if match:
             filename = Path(match[0])
